==> marketing-api-java-sdk-1.1.4-sources.jar: com/tencent/ads/examples/BasicOperations/Insights/GetAsyncReportFiles.java <==
package com.tencent.ads.examples.BasicOperations.Insights;

import com.tencent.ads.ApiContextConfig;
import com.tencent.ads.TencentAds;
import com.tencent.ads.exception.TencentAdsResponseException;
import com.tencent.ads.exception.TencentAdsSDKException;
import com.tencent.ads.model.*;
import java.util.List;

public class GetAsyncReportFiles {
  /** YOUR ACCESS TOKEN */
  public String ACCESS_TOKEN = "YOUR ACCESS TOKEN";

  /** TencentAds */
  public TencentAds tencentAds;

  public Long accountId = null;

  public Long taskId = null;

  public Long fileId = null;

  public List<String> fields = null;

  public void init() {
    this.tencentAds = TencentAds.getInstance();
    this.tencentAds.init(
        new ApiContextConfig().accessToken(ACCESS_TOKEN).isDebug(true)); // debug==true 会打印请求详细信息
    this.tencentAds.useSandbox(); // 默认使用沙箱环境，如果要请求线上，这里需要设为线上环境
    this.buildParams();
  }

  public void buildParams() {}

  public String getAsyncReportFiles() throws Exception {
    String response =
        tencentAds.asyncReportFiles().asyncReportFilesGet(accountId, taskId, fileId, fields);
    return response;
  }

  public static void main(String[] args) {
    try {
      GetAsyncReportFiles getAsyncReportFiles = new GetAsyncReportFiles();
      getAsyncReportFiles.init();
      String response = getAsyncReportFiles.getAsyncReportFiles();
    } catch (TencentAdsResponseException e) {
      e.printStackTrace();
    } catch (TencentAdsSDKException e) {
      e.printStackTrace();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
}

==> marketing-api-java-sdk-1.1.59-sources.jar: com/tencent/ads/examples/BasicOperations/Insights/GetAsyncReportFiles.java <==
package com.tencent.ads.examples.BasicOperations.Insights;

import com.tencent.ads.ApiContextConfig;
import com.tencent.ads.TencentAds;
import com.tencent.ads.exception.TencentAdsResponseException;
import com.tencent.ads.exception.TencentAdsSDKException;
import com.tencent.ads.model.*;
import java.util.List;

public class GetAsyncReportFiles {
  /** YOUR ACCESS TOKEN */
  public String ACCESS_TOKEN = "YOUR ACCESS TOKEN";

  /** TencentAds */
  public TencentAds tencentAds;

  public Long accountId = null;

  public Long taskId = null;

  public Long fileId = null;

  public Boolean weixinOfficialAccountsUpgradeEnabled = null;

  public List<String> fields = null;

  public void init() {
    this.tencentAds = TencentAds.getInstance();
    this.tencentAds.init(
        new ApiContextConfig().accessToken(ACCESS_TOKEN).isDebug(true)); // debug==true 会打印请求详细信息
    this.tencentAds.useSandbox(); // 默认使用沙箱环境，如果要请求线上，这里需要设为线上环境
    this.buildParams();
  }

  public void buildParams() {}

  public String getAsyncReportFiles() throws Exception {
    String response =
        tencentAds
            .asyncReportFiles()
            .asyncReportFilesGet(
                accountId, taskId, fileId, weixinOfficialAccountsUpgradeEnabled, fields);
    return response;
  }

  public static void main(String[] args) {
    try {
      GetAsyncReportFiles getAsyncReportFiles = new GetAsyncReportFiles();
      getAsyncReportFiles.init();
      String response = getAsyncReportFiles.getAsyncReportFiles();
    } catch (TencentAdsResponseException e) {
      e.printStackTrace();
    } catch (TencentAdsSDKException e) {
      e.printStackTrace();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
}
